/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015, 2020 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_cg_main.c
* Version      : Code Generator for RL78/I1C V1.01.06.01 [25 Nov 2020]
* Device(s)    : R5F10NPL
* Tool-Chain   : CCRL
* Description  : This file implements main function.
* Creation Date: 5/12/2021
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_cgc.h"
#include "r_cg_port.h"
#include "r_cg_rtc.h"
#include "r_cg_wdt.h"
#include "r_cg_sau.h"
#include "r_cg_intp.h"
#include "r_cg_lvd.h"
/* Start user code for include. Do not edit comment generated here */
#include "command.h"
#include "cmd.h"				/* CMD Prompt Middleware Layer */
#include "iodefine.h"
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Start user code for global. Do not edit comment generated here */
extern uint8_t g_bat_flag;

 void R_WELCOME_Msg(void);
 void R_RTC_BAT_Detect(void);
 void R_BATTERY_Warning(void);
/* End user code. Do not edit comment generated here */

static void R_MAIN_UserInit(void);
/***********************************************************************************************************************
* Function Name: main
* Description  : This function implements main function.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void main(void)
{
    R_MAIN_UserInit();
    /* Start user code. Do not edit comment generated here */
        
    while (1U)
    {
        NOP();
	COMMAND_PollingProcessing();
	
	if (g_bat_flag == 1)
	{
		R_BATTERY_Warning();
		g_bat_flag = 0;
	}	
	
	R_WDT_Restart();
    }
    
    /* End user code. Do not edit comment generated here */
}
/***********************************************************************************************************************
* Function Name: R_MAIN_UserInit
* Description  : This function adds user code before implementing main function.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
static void R_MAIN_UserInit(void)
{
    /* Start user code. Do not edit comment generated here */
    EI();
    
    /*Start Drivers*/
    CMD_Init();
    CMD_Start();
    
    /*Inital Bat Detect And RTC */
    R_RTC_BAT_Detect();
    
    /*Enable RTC Batt Detection*/
    R_LVD_Start_VRTC();
    
    /*Welcome Message*/
    R_WELCOME_Msg();
    
    /* SW2 Interrupt*/
    R_INTC14_Start();

    /*CMD Ready*/
    CMD_SendString((uint8_t *)"CMD> ");
    
    /* End user code. Do not edit comment generated here */
}

/* Start user code for adding. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_WELCOME_Msg
* Description  : This function prints a welcome message.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_WELCOME_Msg(void)
{
    CMD_SendString((uint8_t *)"\n\r");
    CMD_SendString((uint8_t *)"------------------------------------------------------------\n\r");
    CMD_SendString((uint8_t *)"|       Welcome to the Quick Start Example Project         |\n\r");
    CMD_SendString((uint8_t *)"------------------------------------------------------------\n\r");
    CMD_SendString((uint8_t *)"Enter ""?"" to see a list of commands-----------------------\n\r");
    CMD_SendString((uint8_t *)"\n\r");
}

/***********************************************************************************************************************
* Function Name: R_BATTERY_Detect
* Description  : This function detects if battery is initially inserted.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_RTC_BAT_Detect(void)
{
    VRTCEN = 1U;
    if (LVDVRTCF == 0)  		/*Battery Voltage Flag*/
    {    
	if(RTCPORSR == 0x00)	/*Reads RTC Power_On_Reset Flag*/
	{
		R_RTC_Create();		/*Init RTC*/
		RTCPORSR = 0x01;	/*Sets RTC Power_On_Reset Flag*/		
    		R_RTC_Start();
	}
    }
    else
    {
    	/*Battery Warning Message*/
    	R_BATTERY_Warning();
    }
    
}

/***********************************************************************************************************************
* Function Name: R_BATTERY_Warning
* Description  : This function prints the battery warning message.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_BATTERY_Warning(void)
{
    CMD_SendString((uint8_t *)"\n\r");
    CMD_SendString((uint8_t *)"Warning Missing Battery!\n\r");
    CMD_SendString((uint8_t *)"RTC is Disabled.....\n\r");
    CMD_SendString((uint8_t *)"Please insert battery and reset to enable RTC...\n\r");    
}
/* End user code. Do not edit comment generated here */
