/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015, 2020 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_cg_sau.c
* Version      : Code Generator for RL78/I1C V1.01.06.01 [25 Nov 2020]
* Device(s)    : R5F10NPL
* Tool-Chain   : CCRL
* Description  : This file implements device driver for SAU module.
* Creation Date: 5/12/2021
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_sau.h"
/* Start user code for include. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
volatile uint8_t * gp_uart4_tx_address;        /* uart4 transmit buffer address */
volatile uint16_t  g_uart4_tx_count;           /* uart4 transmit data number */
volatile uint8_t * gp_uart4_rx_address;        /* uart4 receive buffer address */
volatile uint16_t  g_uart4_rx_count;           /* uart4 receive data number */
volatile uint16_t  g_uart4_rx_length;          /* uart4 receive data length */
/* Start user code for global. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_SAU2_Create
* Description  : This function initializes the SAU2 module.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_SAU2_Create(void)
{
    SAU2EN = 1U;    /* enables input clock supply */
    NOP();
    NOP();
    NOP();
    NOP();
    SPS2 = _0020_SAU_CK01_fCLK_2 | _0002_SAU_CK00_fCLK_2;
    R_UART4_Create();
}
/***********************************************************************************************************************
* Function Name: R_UART4_Create
* Description  : This function initializes the UART4 module.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_UART4_Create(void)
{
    ST2 |= _0002_SAUm_CH1_STOP_TRG_ON | _0001_SAUm_CH0_STOP_TRG_ON;
    STMK4 = 1U;     /* disable INTST4 interrupt */
    STIF4 = 0U;     /* clear INTST4 interrupt flag */
    SRMK4 = 1U;     /* disable INTSR4 interrupt */
    SRIF4 = 0U;     /* clear INTSR4 interrupt flag */
    SREMK4 = 1U;    /* disable INTSRE4 interrupt */
    SREIF4 = 0U;    /* clear INTSRE4 interrupt flag */
    /* Set INTSR4 low priority */
    SRPR14 = 1U;
    SRPR04 = 1U;
    /* Set INTST4 low priority */
    STPR14 = 1U;
    STPR04 = 1U;
    SMR20 = _0020_SMR20_DEFAULT_VALUE | _0000_SAU_CLOCK_SELECT_CK00 | _0000_SAU_CLOCK_MODE_CKS | 
            _0002_SAU_MODE_UART | _0000_SAU_TRANSFER_END;
    SCR20 = _0004_SCR20_DEFAULT_VALUE | _8000_SAU_TRANSMISSION | _0000_SAU_TIMING_1 | _0000_SAU_INTSRE_MASK | 
            _0000_SAU_PARITY_NONE | _0080_SAU_LSB | _0010_SAU_STOP_1 | _0003_SAU_LENGTH_8;
    SDR20 = _9A00_SAU2_CH0_BAUDRATE_DIVISOR;
    NFEN0 |= _80_SAU_RXD4_FILTER_ON;
    SIR21 = _0004_SAU_SIRMN_FECTMN | _0002_SAU_SIRMN_PECTMN | _0001_SAU_SIRMN_OVCTMN;
    SMR21 = _0020_SMR21_DEFAULT_VALUE | _0000_SAU_CLOCK_SELECT_CK00 | _0000_SAU_CLOCK_MODE_CKS | 
            _0100_SAU_TRIGGER_RXD | _0000_SAU_EDGE_FALL | _0002_SAU_MODE_UART | _0000_SAU_TRANSFER_END;
    SCR21 = _0004_SCR21_DEFAULT_VALUE | _4000_SAU_RECEPTION | _0000_SAU_TIMING_1 | _0000_SAU_INTSRE_MASK | 
            _0000_SAU_PARITY_NONE | _0080_SAU_LSB | _0010_SAU_STOP_1 | _0003_SAU_LENGTH_8;
    SDR21 = _9A00_SAU2_CH1_BAUDRATE_DIVISOR;
    SO2 |= _0001_SAUm_CH0_DATA_OUTPUT_1;
    SOL2 &= (uint16_t)~_0001_SAUm_CHANNEL0_INVERTED;
    SOE2 |= _0001_SAUm_CH0_OUTPUT_ENABLE;
    /* Set RxD4 pin */
    PFSEG5 &= 0xFBU;
    PM5 |= 0x04U;
    /* Set TxD4 pin */
    PFSEG5 &= 0xFDU;
    P5 |= 0x02U;
    PM5 &= 0xFDU;
}
/***********************************************************************************************************************
* Function Name: R_UART4_Start
* Description  : This function starts the UART4 module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_UART4_Start(void)
{
    SO2 |= _0001_SAUm_CH0_DATA_OUTPUT_1;
    SOE2 |= _0001_SAUm_CH0_OUTPUT_ENABLE;
    SS2 |= _0002_SAUm_CH1_START_TRG_ON | _0001_SAUm_CH0_START_TRG_ON;
    STIF4 = 0U;     /* clear INTST4 interrupt flag */
    SRIF4 = 0U;     /* clear INTSR4 interrupt flag */
    STMK4 = 0U;     /* enable INTST4 interrupt */
    SRMK4 = 0U;     /* enable INTSR4 interrupt */
}
/***********************************************************************************************************************
* Function Name: R_UART4_Stop
* Description  : This function stops the UART4 module operation.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_UART4_Stop(void)
{
    STMK4 = 1U;     /* disable INTST4 interrupt */
    SRMK4 = 1U;     /* disable INTSR4 interrupt */
    ST2 |= _0002_SAUm_CH1_STOP_TRG_ON | _0001_SAUm_CH0_STOP_TRG_ON;
    SOE2 &= (uint16_t)~_0001_SAUm_CH0_OUTPUT_ENABLE;
    STIF4 = 0U;     /* clear INTST4 interrupt flag */
    SRIF4 = 0U;     /* clear INTSR4 interrupt flag */
}
/***********************************************************************************************************************
* Function Name: R_UART4_Receive
* Description  : This function receives UART4 data.
* Arguments    : rx_buf -
*                    receive buffer pointer
*                rx_num -
*                    buffer size
* Return Value : status -
*                    MD_OK or MD_ARGERROR
***********************************************************************************************************************/
MD_STATUS R_UART4_Receive(uint8_t * const rx_buf, uint16_t rx_num)
{
    MD_STATUS status = MD_OK;

    if (rx_num < 1U)
    {
        status = MD_ARGERROR;
    }
    else
    {
        g_uart4_rx_count = 0U;
        g_uart4_rx_length = rx_num;
        gp_uart4_rx_address = rx_buf;
    }

    return (status);
}
/***********************************************************************************************************************
* Function Name: R_UART4_Send
* Description  : This function sends UART4 data.
* Arguments    : tx_buf -
*                    transfer buffer pointer
*                tx_num -
*                    buffer size
* Return Value : status -
*                    MD_OK or MD_ARGERROR
***********************************************************************************************************************/
MD_STATUS R_UART4_Send(uint8_t * const tx_buf, uint16_t tx_num)
{
    MD_STATUS status = MD_OK;

    if (tx_num < 1U)
    {
        status = MD_ARGERROR;
    }
    else
    {
        gp_uart4_tx_address = tx_buf;
        g_uart4_tx_count = tx_num;
        STMK4 = 1U;    /* disable INTST4 interrupt */
        TXD4 = *gp_uart4_tx_address;
        gp_uart4_tx_address++;
        g_uart4_tx_count--;
        STMK4 = 0U;    /* enable INTST4 interrupt */
    }

    return (status);
}

/* Start user code for adding. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
