/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015, 2020 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_cg_sau_user.c
* Version      : Code Generator for RL78/I1C V1.01.06.01 [25 Nov 2020]
* Device(s)    : R5F10NPL
* Tool-Chain   : CCRL
* Description  : This file implements device driver for SAU module.
* Creation Date: 5/12/2021
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_sau.h"
/* Start user code for include. Do not edit comment generated here */
#include "cmd.h"
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
#pragma interrupt r_uart4_interrupt_send(vect=INTST4)
#pragma interrupt r_uart4_interrupt_receive(vect=INTSR4)
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
extern volatile uint8_t * gp_uart4_tx_address;         /* uart4 send buffer address */
extern volatile uint16_t  g_uart4_tx_count;            /* uart4 send data number */
extern volatile uint8_t * gp_uart4_rx_address;         /* uart4 receive buffer address */
extern volatile uint16_t  g_uart4_rx_count;            /* uart4 receive data number */
extern volatile uint16_t  g_uart4_rx_length;           /* uart4 receive data length */
/* Start user code for global. Do not edit comment generated here */
uint8_t g_uart4_received_byte;		       /* uart4 received byte */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: r_uart4_interrupt_receive
* Description  : None
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
static void __near r_uart4_interrupt_receive(void)
{
    volatile uint8_t rx_data;
    volatile uint8_t err_type;
    
    err_type = (uint8_t)(SSR21 & 0x0007U);
    SIR21 = (uint16_t)err_type;

    if (err_type != 0U)
    {
        r_uart4_callback_error(err_type);
    }
    
    rx_data = RXD4;

    if (g_uart4_rx_length > g_uart4_rx_count)
    {
        *gp_uart4_rx_address = rx_data;
        gp_uart4_rx_address++;
        g_uart4_rx_count++;

        if (g_uart4_rx_length == g_uart4_rx_count)
        {
            r_uart4_callback_receiveend();
        }
    }
    else
    {
        r_uart4_callback_softwareoverrun(rx_data);
    }
}
/***********************************************************************************************************************
* Function Name: r_uart4_interrupt_send
* Description  : None
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
static void __near r_uart4_interrupt_send(void)
{
    if (g_uart4_tx_count > 0U)
    {
        TXD4 = *gp_uart4_tx_address;
        gp_uart4_tx_address++;
        g_uart4_tx_count--;
    }
    else
    {
        r_uart4_callback_sendend();
    }
}
/***********************************************************************************************************************
* Function Name: r_uart4_callback_receiveend
* Description  : This function is a callback function when UART4 finishes reception.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
static void r_uart4_callback_receiveend(void)
{
    /* Start user code. Do not edit comment generated here */
    CMD_ReceiveEndCallback(g_uart4_received_byte);
    R_UART4_Receive(&g_uart4_received_byte, 1);
    /* End user code. Do not edit comment generated here */
}
/***********************************************************************************************************************
* Function Name: r_uart4_callback_softwareoverrun
* Description  : This function is a callback function when UART4 receives an overflow data.
* Arguments    : rx_data -
*                    receive data
* Return Value : None
***********************************************************************************************************************/
static void r_uart4_callback_softwareoverrun(uint16_t rx_data)
{
    /* Start user code. Do not edit comment generated here */
    NOP();
    /* End user code. Do not edit comment generated here */
}
/***********************************************************************************************************************
* Function Name: r_uart4_callback_sendend
* Description  : This function is a callback function when UART4 finishes transmission.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
static void r_uart4_callback_sendend(void)
{
    /* Start user code. Do not edit comment generated here */
    CMD_SendEndCallback();
    /* End user code. Do not edit comment generated here */
}
/***********************************************************************************************************************
* Function Name: r_uart4_callback_error
* Description  : This function is a callback function when UART4 reception error occurs.
* Arguments    : err_type -
*                    error type value
* Return Value : None
***********************************************************************************************************************/
static void r_uart4_callback_error(uint8_t err_type)
{
    /* Start user code. Do not edit comment generated here */
    NOP();
    /* End user code. Do not edit comment generated here */
}

/* Start user code for adding. Do not edit comment generated here */

/******************************************************************************
* Function Name    : void UART4_DRIVER_Start(void)
* Description      : UART4_DRIVER_Start
* Arguments        : None
* Functions Called :R_UART4_Start()
* Return Value     : None
******************************************************************************/
void UART4_DRIVER_Start(void)
{
	R_UART4_Start();
	
	/* Start receive data byte */
	R_UART4_Receive(&g_uart4_received_byte, 1);
}
/* End user code. Do not edit comment generated here */
