/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIESREGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2013, 2015 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : section_init.c
* Version      : 
* Device(s)    : RL78/I1C
* Tool-Chain   : CCRL
* Description  : Section initialization routine
* Creation Date: 
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/

/***********************************************************************************************************************
Macro definitions
***********************************************************************************************************************/

/***********************************************************************************************************************
Typedef definitions
***********************************************************************************************************************/
typedef struct 
{
    char __near *ram_sectop;        /*Start address of section                  */
    char __near *ram_secend;        /*End address + 1 of section                */
} bsec_t;

typedef struct 
{
    char __far *rom_sectop;         /*Start address of copy source section      */
    char __far *rom_secend;         /*End address + 1 of copy source section    */
    char __near *ram_sectop;        /*Start address of copy destination section */
} dsec_t;

/***********************************************************************************************************************
Imported global variables and functions (from other files)
***********************************************************************************************************************/

/***********************************************************************************************************************
Exported global variables and functions (to be accessed by other files)
***********************************************************************************************************************/

/***********************************************************************************************************************
Private global variables and functions
***********************************************************************************************************************/

/* Not use the bsec_table: since all RAM area is init by cstart before */
#if 0
const bsec_t bsec_table[] = 
{
    {
        (char __near *)__sectop(".bss"),
        (char __near *)__secend(".bss")
    },
    {
        (char __near *)__sectop(".sbss"),
        (char __near *)__secend(".sbss")
    },
//#ifdef __DEBUG    
    {
        (char __near *)__sectop("EMBss_n"),
        (char __near *)__secend("EMBss_n")
    },
    {
        (char __near *)__sectop("WpBss_n"),
        (char __near *)__secend("WpBss_n")
    }
//#endif
};
#define BSEC_MAX                        (sizeof(bsec_table) / sizeof(bsec_t))   /*Number of BSS sections to be initialized to 0*/
#endif

const dsec_t dsec_table[] = 
{
    {
        __sectop(".data"),
        __secend(".data"),
        (char __near *)__sectop(".dataR")
    },
    {
        __sectop(".sdata"),
        __secend(".sdata"),
        (char __near *)__sectop(".sdataR")
    },
//#ifdef __DEBUG 
    {
        __sectop("EMData_n"),
        __secend("EMData_n"),
        (char __near *)__sectop("EMDataR_n")
    },
    {
        __sectop("WpData_n"),
        __secend("WpData_n"),
        (char __near *)__sectop("WpDataR_n")
    },
//#endif
};

#define DSEC_MAX                        (sizeof(dsec_table) / sizeof(dsec_t))   /*Number of DATA sections to be copied*/

/***********************************************************************************************************************
* Function Name: void section_init(void)
* Description  : Initialize memory sections:
*              : . ROMization
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void section_init(void)
{
    unsigned int i;
    char __far *rom_p;
    char __near *ram_p;
        
    /* Data Section Init */
    for (i = 0; i < DSEC_MAX; i++) 
    {
        rom_p = dsec_table[i].rom_sectop;
        ram_p = dsec_table[i].ram_sectop;
        for ( ; rom_p != dsec_table[i].rom_secend; rom_p++, ram_p++) 
        {
            *ram_p = *rom_p;
        }
    }
}
